@@ -1,6 +1,7 @@
 # $Header:$
 
 use strict;
+use warnings;
 
 package Petal::CodePerl::Compiler;
 
@@ -11,30 +12,9 @@ use Carp qw( confess );
 
 use Data::Dumper qw(Dumper);
 
-use Petal::CodePerl::Parser;
-
 our $root = holder();
 
-my $parser;
-
-# handy for being able alter the grammar during development
-
-if(0)
-{
-	require Parse::RecDescent;
-
-	my $petales_grammar = do "grammar" || die "No grammar";
-
-	local $Parse::RecDescent::skip = "";
-	$::RD_HINT = 1;
-	#$::RD_TRACE = 1;
-
-	$parser = Parse::RecDescent->new($petales_grammar) || die "Parser didn't compile";
-}
-else
-{
-	$parser = Petal::CodePerl::Parser->new;
-}
+our $Parser;
 
 sub compile
 {
@@ -47,6 +27,8 @@ sub compile
 
 sub compileRule
 {
+	require Petal::CodePerl::GrammarLoader;
+
 	my $self = shift;
 
 	my $rule = shift;
@@ -55,7 +37,7 @@ sub compileRule
 
 	my $expr_ref = ref($expr) ? $expr : \$expr;
 
-	my $comp = $parser->$rule($expr_ref);
+	my $comp = $Parser->$rule($expr_ref);
 
 	if (length($$expr_ref))
 	{
